@@ -15,7 +15,7 @@ use Tags::HTML::Page::Begin;
 use Tags::HTML::Page::End;
 use Tags::Output::Raw;
 
-our $VERSION = 0.10;
+our $VERSION = 0.11;
 
 sub call {
 	my ($self, $env) = @_;
@@ -141,7 +141,7 @@ sub _tags {
 	my $self = shift;
 
 	if ($self->flag_begin) {
-		Tags::HTML::Page::Begin->new(
+		my $page_begin = Tags::HTML::Page::Begin->new(
 			'author' => $self->author,
 			'css' => $self->css,
 			defined $self->css_init ? (
@@ -156,7 +156,9 @@ sub _tags {
 			'script_js' => $self->script_js,
 			'script_js_src' => $self->script_js_src,
 			'tags' => $self->tags,
-		)->process;
+		);
+		$page_begin->process_css;
+		$page_begin->process;
 	}
 
 	$self->_tags_middle;
@@ -515,6 +517,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.10
+0.11
 
 =cut
